@@ -10,23 +10,22 @@ Module for defining configuration classes that define the behavior of a yolox mo
 from typing import Any, Dict, List, Optional
 
 import related
+from attr import define
 from config_builder import BaseConfigClass
-from loguru import logger
-from mlcvzoo_base.api.configuration import Configuration
+from mlcvzoo_base.api.configuration import InferenceConfig, ModelConfiguration
 from mlcvzoo_base.configuration.annotation_handler_config import AnnotationHandlerConfig
 from mlcvzoo_base.configuration.class_mapping_config import ClassMappingConfig
-from mlcvzoo_base.configuration.detector_configs import DetectorConfig
 from mlcvzoo_base.configuration.reduction_mapping_config import ReductionMappingConfig
 
 from mlcvzoo_yolox.exp.default import YOLOXExperiments
 
 
-@related.mutable(strict=True)
+@define
 class YOLOXExperimentConfig(BaseConfigClass):
+    __related_strict__ = True
+
     # Type of the yolox experiments that should be used as base experiment
     exp_type: str = related.StringField()
-    # name of your experiment
-    exp_name: Optional[str] = related.StringField(required=False, default=None)
 
     # Dictionary for overwriting attributes of the loaded
     # base experiment
@@ -42,22 +41,15 @@ class YOLOXExperimentConfig(BaseConfigClass):
                 f"{[str(d.value.upper()) for d in YOLOXExperiments]}"
             )
 
-        if self.exp_name is None:
-            logger.warning(
-                "DEPRECATED: The exp_name attribute is deprecated "
-                "and will be removed in future versions "
-            )
-
         return True
 
 
-@related.mutable(strict=True)
-class YOLOXInferenceConfig(BaseConfigClass):
+@define
+class YOLOXInferenceConfig(InferenceConfig):
+    __related_strict__ = True
+
     input_dim: List[int] = related.SequenceField(cls=int)
 
-    checkpoint_path: str = related.StringField()
-
-    score_threshold: float = related.FloatField()
     nms_threshold: float = related.FloatField()
 
     device: str = related.StringField()
@@ -68,13 +60,16 @@ class YOLOXInferenceConfig(BaseConfigClass):
     reduction_class_mapping: Optional[ReductionMappingConfig] = related.ChildField(
         cls=ReductionMappingConfig, required=False, default=None
     )
+    config_path: Optional[str] = None
 
     def check_values(self) -> bool:
         return self.device in ["gpu", "cpu"] and len(self.input_dim) == 2
 
 
-@related.mutable(strict=True)
+@define
 class YOLOXTRTConfig(BaseConfigClass):
+    __related_strict__ = True
+
     trt_checkpoint_path: str = related.StringField()
     trt_engine_path: str = related.StringField()
 
@@ -88,13 +83,15 @@ class YOLOXTRTConfig(BaseConfigClass):
     fp16: bool = related.BooleanField(default=True)
 
 
-@related.mutable(strict=True)
-class YOLOXTrainArgparseConfig(BaseConfigClass, Configuration):
+@define
+class YOLOXTrainArgparseConfig(BaseConfigClass):
     """
     argparse parameter as stated in yolox/tools/train.py
 
     """
 
+    __related_strict__ = True
+
     # NOTE: This is here to indicate that we did not forget the "exp_file" and "experiment_name"
     #       argparse parameter. Since we are using the YOLOXExperimentConfig to define one
     #       experiment config for inference as well as fore training, we are creating a
@@ -136,8 +133,9 @@ class YOLOXTrainArgparseConfig(BaseConfigClass, Configuration):
     logger: str = related.StringField(default="tensorboard")
 
 
-@related.mutable(strict=True)
-class YOLOXTrainConfig(BaseConfigClass, Configuration):
+@define
+class YOLOXTrainConfig(BaseConfigClass):
+    __related_strict__ = True
 
     argparse_config: YOLOXTrainArgparseConfig = related.ChildField(
         cls=YOLOXTrainArgparseConfig
@@ -151,23 +149,11 @@ class YOLOXTrainConfig(BaseConfigClass, Configuration):
         cls=AnnotationHandlerConfig
     )
 
-    output_dir: Optional[str] = related.StringField(required=False, default=None)
 
-    def check_values(self) -> bool:
+@define
+class YOLOXConfig(ModelConfiguration):
+    __related_strict__ = True
 
-        if self.output_dir is None:
-            logger.debug(
-                "The YOLOXTrainConfig.output_dir is set to None. "
-                "Therefore the yolox trainer will use the output_dir"
-                "which is specified in the configuration attribute"
-                " YOLOXTrainConfig.argparse_config.exp_file"
-            )
-
-        return True
-
-
-@related.mutable(strict=True)
-class YOLOXConfig(BaseConfigClass, Configuration):
     class_mapping: ClassMappingConfig = related.ChildField(cls=ClassMappingConfig)
 
     experiment_config: YOLOXExperimentConfig = related.ChildField(
@@ -185,7 +171,3 @@ class YOLOXConfig(BaseConfigClass, Configuration):
     train_config: Optional[YOLOXTrainConfig] = related.ChildField(
         cls=YOLOXTrainConfig, required=False, default=None
     )
-
-    base_config: DetectorConfig = related.ChildField(
-        cls=DetectorConfig, default=DetectorConfig()
-    )
